summaryrefslogtreecommitdiff
path: root/png.h
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2002-05-01 16:55:46 -0500
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2009-04-06 16:07:02 -0500
commit299d73503c16eaff09c3f03918d6c283d929d13e (patch)
tree8ba8c9a949f38a517d9983d9147ebc9a69b84c66 /png.h
parent25d8224d15881020f2900ed5437c1567e3b52e97 (diff)
downloadlibpng-299d73503c16eaff09c3f03918d6c283d929d13e.tar.gz
Imported from libpng-1.2.3rc3.tarv1.2.3rc3
Diffstat (limited to 'png.h')
-rw-r--r--png.h32
1 files changed, 18 insertions, 14 deletions
diff --git a/png.h b/png.h
index 25c1e2f70..6a58f0bcd 100644
--- a/png.h
+++ b/png.h
@@ -1,6 +1,6 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.2.3rc2 - May 1, 2002
* Copyright (c) 1998-2002 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -8,7 +8,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.2.3rc2 - May 1, 2002: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -86,7 +86,7 @@
* 1.2.2rc1 12 10202 12.so.0.1.2.2rc1
* 1.0.13 10 10013 10.so.0.1.0.13
* 1.2.2 12 10202 12.so.0.1.2.2
- * 1.2.3rc1 12 10203 12.so.0.1.2.3rc1
+ * 1.2.3rc1-3 12 10203 12.so.0.1.2.3rc1-3
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -116,8 +116,8 @@
* If you modify libpng you may insert additional notices immediately following
* this sentence.
*
* libpng versions 1.0.7, July 1, 2000, through 1.2.3rc2, May 1, 2002, are
* Copyright (c) 2000-2001 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.0.6
* with the following individuals added to the list of Contributing Authors
*
@@ -227,7 +227,7 @@
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.2.3rc2 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*
* Libpng only has three year fields. One is a 2-byte unsigned integer
@@ -283,7 +283,7 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.2.3rc2"
+#define PNG_LIBPNG_VER_STRING "1.2.3rc3"
#define PNG_LIBPNG_VER_SONUM 0
#define PNG_LIBPNG_VER_DLLNUM %DLLNUM%
@@ -295,7 +295,7 @@
/* This should match the numeric part of the final component of
* PNG_LIBPNG_VER_STRING, omitting any leading zero: */
-#define PNG_LIBPNG_VER_BUILD 2
+#define PNG_LIBPNG_VER_BUILD 3
#define PNG_LIBPNG_BUILD_ALPHA 1
#define PNG_LIBPNG_BUILD_BETA 2
@@ -1263,9 +1263,9 @@ struct png_struct_def
/* This prevents a compiler error in png.c if png.c and png.h are both at
- version 1.2.3rc2
+ version 1.2.3rc3
*/
-typedef png_structp version_1_2_3rc2;
+typedef png_structp version_1_2_3rc3;
typedef png_struct FAR * FAR * png_structpp;
@@ -1739,6 +1739,12 @@ extern PNG_EXPORT(void,png_set_write_fn) PNGARG((png_structp png_ptr,
extern PNG_EXPORT(void,png_default_write_data) PNGARG((png_structp png_ptr,
png_bytep data, png_size_t length));
+#if defined(PNG_WRITE_FLUSH_SUPPORTED)
+#if !defined(PNG_NO_STDIO)
+PNG_EXPORT(void,png_default_flush) PNGARG((png_structp png_ptr));
+#endif
+#endif
+
/* Replace the default data input function with a user supplied one. */
extern PNG_EXPORT(void,png_set_read_fn) PNGARG((png_structp png_ptr,
png_voidp io_ptr, png_rw_ptr read_data_fn));
@@ -2405,7 +2411,7 @@ extern PNG_EXPORT(void,png_set_strip_error_numbers) PNGARG((png_structp
/* Maintainer: Put new public prototypes here ^, in libpng.3, and project defs */
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.2.3rc2 - May 1, 2002 (header)\n"
+ " libpng version 1.2.3rc3 - May 1, 2002 (header)\n"
#ifdef PNG_READ_COMPOSITE_NODIV_SUPPORTED
/* With these routines we avoid an integer divide, which will be slower on
@@ -2712,11 +2718,9 @@ PNG_EXTERN void png_calculate_crc PNGARG((png_structp png_ptr, png_bytep ptr,
#if defined(PNG_WRITE_FLUSH_SUPPORTED)
PNG_EXTERN void png_flush PNGARG((png_structp png_ptr));
-#if !defined(PNG_NO_STDIO)
-PNG_EXTERN void png_default_flush PNGARG((png_structp png_ptr));
-#endif
#endif
+
/* Place a 32-bit number into a buffer in PNG byte order (big-endian).
* The only currently known PNG chunks that use signed numbers are
* the ancillary extension chunks, oFFs and pCAL.
@@ -1,6 +1,6 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.2.3rc2 - May 1, 2002
+ * libpng version 1.2.3rc3 - May 1, 2002
* Copyright (c) 1998-2002 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -8,7 +8,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.2.3rc2 - May 1, 2002: Glenn
+ * libpng versions 0.97, January 1998, through 1.2.3rc3 - May 1, 2002: Glenn
* See also "Contributing Authors", below.
*
@@ -116,8 +116,8 @@
* this sentence.
*
- * libpng versions 1.0.7, July 1, 2000, through 1.2.3rc2, May 1, 2002, are
- * Copyright (c) 2000-2001 Glenn Randers-Pehrson, and are
+ * libpng versions 1.0.7, July 1, 2000, through 1.2.3rc3, May 1, 2002, are
+ * Copyright (c) 2000-2002 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.0.6
* with the following individuals added to the list of Contributing Authors
@@ -227,7 +227,7 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.2.3rc2 are Y2K compliant. It is my belief that earlier
+ * upward through 1.2.3rc3 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*